@@ -261,18 +261,23 @@ bool GameVariantDelegate::eventFilter(QObject* watched, QEvent* event) {
 ///////////////////////////////////////////////////////////////////////////////
 
 SudokuGame::SudokuGame(const QString& name, uint order, GameVariantCollection* collection)
-	: GameVariant(name, collection), m_order(order), m_graph(0)
+	: GameVariant(name, collection), m_order(order), m_graph(nullptr)
 {
 	// TODO load from settings
 	m_symmetry = 0;
 }
 
+SudokuGame::~SudokuGame()
+{
+	delete m_graph;
+}
+
 bool SudokuGame::canConfigure() const {
 	return true;
 }
 
 bool SudokuGame::configure() {
-	KMessageBox::information(0, i18n("Configuration not yet implemented"), "");
+	KMessageBox::information(nullptr, i18n("Configuration not yet implemented"), "");
 	return false;
 }
 
@@ -306,7 +311,7 @@ Game SudokuGame::createGame(int difficulty, int symmetry) {
 
 KsView* SudokuGame::createView(const Game& /*game*/) const {
 	qCDebug(KSudokuLog) << "KsView* ksudoku::SudokuGame::createView()";
-	return 0;
+	return nullptr;
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -314,17 +319,22 @@ KsView* SudokuGame::createView(const Game& /*game*/) const {
 ///////////////////////////////////////////////////////////////////////////////
 
 RoxdokuGame::RoxdokuGame(const QString& name, uint order, GameVariantCollection* collection)
-	: GameVariant(name, collection), m_order(order), m_graph(0)
+	: GameVariant(name, collection), m_order(order), m_graph(nullptr)
 {
 	m_symmetry = 0;
 }
 
+RoxdokuGame::~RoxdokuGame()
+{
+	delete m_graph;
+}
+
 bool RoxdokuGame::canConfigure() const {
 	return true;
 }
 
 bool RoxdokuGame::configure() {
-	KMessageBox::information(0, i18n("Configuration not yet implemented"), "");
+	KMessageBox::information(nullptr, i18n("Configuration not yet implemented"), "");
 	return false;
 }
 
@@ -367,11 +377,16 @@ KsView* RoxdokuGame::createView(const Game& /*game*/) const {
 
 CustomGame::CustomGame(const QString& name, const QUrl& url,
                        GameVariantCollection* collection)
-	: GameVariant(name, collection), m_url(url), m_graph(0)
+    : GameVariant(name, collection), m_url(url), m_graph(nullptr)
 {
 	m_symmetry = 0;
 }
 
+CustomGame::~CustomGame()
+{
+	delete m_graph;
+}
+
 bool CustomGame::canConfigure() const {
 	return false;
 }
